@@ -251,11 +251,15 @@ Sncf <- function(x, y, z, w = NULL, df = NULL, type = "boot", resamp = 1000,
 ################################################################################
 plot.Sncf <- function(x, xmax = 0, ylim = c(-1, 1), add = FALSE, ...) {
   ##############################################################################
+  args.default <- list(xlab = "Distance", ylab = "Correlation")
+  args.input <- list(...)
+  args <- c(args.default[!names(args.default) %in% names(args.input)], args.input)
+  
   xmax <- ifelse(xmax == 0, x$max.distance, xmax)
   cbar <- x$real$cbar
   if (!add) {
-    plot(x$real$predicted$x, x$real$predicted$y, xlim = c(0, xmax), 
-         ylim = ylim, type = "l", xlab = "Distance", ylab = "Correlation")
+    do.call(plot, c(list(x = x$real$predicted$x, y = x$real$predicted$y, 
+                         xlim = c(0, xmax), ylim = ylim, type = "l"), args))
   }
   if (!is.null(x$boot$boot.summary)) {
     polygon(c(x$boot$boot.summary$predicted$x, rev(x$boot$boot.summary$predicted$x)), 
@@ -279,8 +283,7 @@ plot.Sncf <- function(x, xmax = 0, ylim = c(-1, 1), add = FALSE, ...) {
 print.Sncf <- function(x, ...) {
   ##############################################################################
   cat("This is an object of class Sncf produced by the call:\n\n", x$call, 
-      "\n\n Use summary() or plot() for inspection,  
-      (or print.default() to see all the gory details).")
+      "\n\n Use summary() or plot() for inspection (or print.default() to see all the gory details).", ...)
 }
 
 #' @title Summarizing nonparametric spatial correlation-functions
@@ -400,7 +403,6 @@ Sncf.srf <- function(x, y, z, w = NULL, avg = NULL, avg2 = NULL, corr = TRUE,
   # smoothing spline as an equivalent kernel) as discussed in 
   # Bjornstad et al. (1999; Trends in Ecology and Evolution 14:427-431)
   ##############################################################################
-  
   p <- dim(z)[2]
   n <- dim(z)[1]
   
@@ -567,9 +569,13 @@ Sncf.srf <- function(x, y, z, w = NULL, avg = NULL, avg2 = NULL, corr = TRUE,
 ################################################################################
 plot.Sncf.cov <- function(x, xmax = 0, ...) {
   ##############################################################################
+  args.default <- list(xlab = "Distance", ylab = "Covariance")
+  args.input <- list(...)
+  args <- c(args.default[!names(args.default) %in% names(args.input)], args.input)
+  
   xmax <- ifelse(xmax == 0, max(x$real$predicted$x), xmax)
-  plot(x$real$predicted$x, x$real$predicted$y, xlim = c(0, xmax), 
-       type = "l", xlab = "Distance", ylab = "Covariance")
+  do.call(plot, c(list(x = x$real$predicted$x, y = x$real$predicted$y, 
+                       xlim = c(0, xmax), type = "l"), args))
   if (!is.null(x$boot$boot.summary)) {
     polygon(c(x$boot$boot.summary$predicted$x, rev(x$boot$boot.summary$predicted$x)), 
             c(x$boot$boot.summary$predicted$y["0.025", ], 
