@@ -209,14 +209,17 @@ plot.correlog <- function(x, ...) {
   # this is the generic plot function for correlog objects
   # sigificant values are represented by filled cirles
   ##############################################################################
-  plot(x$mean.of.class, x$correlation, ylab = 'correlation', 
-       xlab = 'distance (mean-of-class)')
+  args.default <- list(xlab = "distance (mean-of-class)", ylab = "correlation", 
+                       main = "Correlogram")
+  args.input <- list(...)
+  args <- c(args.default[!names(args.default) %in% names(args.input)], args.input)
+  
+  do.call(plot, c(list(x = x$mean.of.class, y = x$correlation), args))
   lines(x$mean.of.class, x$correlation)
   if (!is.null(x$p)) {
     points(x$mean.of.class[x$p < 0.025], x$correlation[x$p < 0.025], pch = 21, 
            bg = "black")
   }
-  title("Correlogram")
 }
 
 #' @title Non-cenetered spatial (cross-)correlogram
@@ -269,7 +272,7 @@ plot.correlog <- function(x, ...) {
 #' @export
 ################################################################################
 correlog.nc <- function(x, y, z, w = NULL, increment, resamp = 1000, na.rm = FALSE, 
-                        latlon = FALSE, quiet = FALSE){
+                        latlon = FALSE, quiet = FALSE) {
   ##############################################################################
   # correlog.nc estimates the noncentred correlogram
   # and cross-correlogram. Bjornstad et al. (1999; Trends in Ecology and
@@ -293,7 +296,7 @@ correlog.nc <- function(x, y, z, w = NULL, increment, resamp = 1000, na.rm = FAL
   if (latlon) {
     # these are geographic distances from lat-lon coordinates
     dmat <- gcdist(x, y)
-  } else{
+  } else {
     # these are geographic distances from euclidian coordinates
     dmat <- sqrt(outer(x, x, "-")^2 + outer(y, y, "-")^2)
   }
